import { __awaiter } from 'tslib';
import { EventEmitter, Component, ViewChild, Output, Input, NgModule } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import BpmnJS from 'bpmn-js/dist/bpmn-modeler.production.min.js';

class NgxThreeoBpmnComponent {
    constructor(http) {
        this.http = http;
        this.importDone = new EventEmitter();
        this.createEnded = new EventEmitter();
        this.connectEnded = new EventEmitter();
        this.elementClicked = new EventEmitter();
        this.bpmnJS = new BpmnJS();
        this.bpmnJS.on('import.done', ({ obj, error }) => {
            if (!error) {
                this.bpmnJS.get('canvas').zoom('fit-viewport');
                this.importDone.emit(obj);
            }
        });
        this.bpmnJS.on('create.ended', (obj) => {
            if (!obj)
                return;
            this.createEnded.emit(obj);
        });
        this.bpmnJS.on('connect.ended', (obj) => {
            this.connectEnded.emit(obj);
        });
        this.bpmnJS.on('element.dblclick', (obj) => {
            this.elementClicked.emit(obj);
        });
    }
    ngAfterContentInit() {
        this.bpmnJS.attachTo(this.el.nativeElement);
    }
    ngOnChanges(changes) {
        // re-import whenever the url changes
        if (changes['xml']) {
            this.importDiagram(changes['xml'].currentValue);
        }
    }
    ngOnDestroy() {
        this.bpmnJS.destroy();
    }
    /**
     * Creates a Promise to import the given XML into the current
     * BpmnJS instance, then returns it as an Observable.
     *
     * @see https://github.com/bpmn-io/bpmn-js-callbacks-to-promises#importxml
     */
    importDiagram(xml) {
        if (!xml) {
            this.bpmnJS.get('canvas').zoom('fit-viewport');
            return;
        }
        this.bpmnJS.importXML(xml);
    }
    salvar() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.bpmnJS.saveXML();
        });
    }
    updateLabel(id, name) {
        var elementRegistry = this.bpmnJS.get('elementRegistry');
        var sequenceFlowElement = elementRegistry.get(id);
        const modeling = this.bpmnJS.get('modeling');
        modeling.updateLabel(sequenceFlowElement, name);
    }
    updateProperties(element, properties) {
        var modeling = this.bpmnJS.get('modeling');
        modeling.updateProperties(element, properties);
    }
}
NgxThreeoBpmnComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-threeo-bpmn',
                template: `<div #ref class="diagram-container"></div>`,
                styles: [`
    .diagram-container {
      height: 100%;
      width: 100%;
    }
  `]
            },] }
];
NgxThreeoBpmnComponent.ctorParameters = () => [
    { type: HttpClient }
];
NgxThreeoBpmnComponent.propDecorators = {
    el: [{ type: ViewChild, args: ['ref', { static: true },] }],
    importDone: [{ type: Output }],
    createEnded: [{ type: Output }],
    connectEnded: [{ type: Output }],
    elementClicked: [{ type: Output }],
    xml: [{ type: Input }]
};

class NgxThreeoBpmnModule {
}
NgxThreeoBpmnModule.decorators = [
    { type: NgModule, args: [{
                declarations: [NgxThreeoBpmnComponent],
                imports: [],
                exports: [NgxThreeoBpmnComponent]
            },] }
];

/*
 * Public API Surface of ngx-threeo-bpmn
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgxThreeoBpmnComponent, NgxThreeoBpmnModule };
//# sourceMappingURL=ngx-threeo-bpmn.js.map
